@@ -579,8 +579,24 @@ def pyminer_cell_signals_main(gene_lists,
         'hsapiens':'9606.protein.actions.v11.0.txt',
         'mmusculus':'10090.protein.actions.v11.0.txt'
     }
+    ## double check that it exists!
+    putative_human_file = os.path.join(stringdb_dir,organism_action_files['hsapiens'])
+    if not os.path.isfile(putative_human_file):
+        print("we couldn't find the string-db interactions in the supplied string_db dir:")
+        print(stringdb_dir)
+        print("will look around a bit!")
+        from pyminer import pyminer
+        script_dir = os.path.dirname(pyminer.__file__)
+        putative_relative_human_file = os.path.join(script_dir,organism_action_files['hsapiens'])
+        print(putative_relative_human_file)
+        if os.path.isfile(putative_relative_human_file):
+            print("\n\nFound it!\n", "using this as the stringdb_dir:",script_dir)
+            stringdb_dir = script_dir
+        else:
+            print("\n\n\n\nWARNING! couldn't find the right files in the stringdb_dir:",stringdb_dir)
+            return()
 
-
+    ## carry on..
     if organism not in organism_action_files:
         convert_to_human = True
 
@@ -1041,7 +1057,7 @@ def pyminer_cell_signals_main(gene_lists,
     #####################################################################################
 
     if organism in organism_action_files:
-        db_file = stringdb_dir+organism_action_files[organism]
+        db_file = os.path.join(stringdb_dir,organism_action_files[organism])
 
     #########
     ## first we'll load into memory only the interactions that stand
