@@ -9,10 +9,10 @@ import random
 import h5py
 try:
     from pyminer.common_functions import *
-    from pyminer.pyminer_make_pyminer_obj import pyminer_obj
+    from pyminer.pyminer_objs import pyminer_obj
 except:
     from common_functions import *
-    from pyminer_make_pyminer_obj import pyminer_obj
+    from pyminer_objs import pyminer_obj
 
 ##############################################################
 
